@@ -11,7 +11,6 @@
 #ifndef EDITORTAB_H
 #define EDITORTAB_H
 
-#include "resizewatcher.h"
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -19,11 +18,36 @@
 #include "config-lokalize.h"
 #include "lokalizetabpagebase.h"
 #include "pos.h"
+#include "resizewatcher.h"
 
-#include <KProcess>
-
-#include <QHash>
 #include <QMap>
+#include <QProcess>
+
+class AltTransView;
+class Catalog;
+class CatalogView;
+class EditorView;
+class MergeView;
+class MsgCtxtView;
+class Project;
+class KActionCategory;
+class KFind;
+class KProcess;
+class KReplace;
+class KToolBarPopupAction;
+class KXMLGUIClient;
+
+class KFind;
+class KReplace;
+class KActionCategory;
+class KToolBarPopupAction;
+class Project;
+class Catalog;
+class EditorView;
+class MergeView;
+class CatalogView;
+class MsgCtxtView;
+class AltTransView;
 
 namespace Sonnet
 {
@@ -37,21 +61,6 @@ namespace TM
 {
 class TMView;
 }
-
-#include <kxmlguiclient.h>
-
-class KFind;
-class KReplace;
-class KActionCategory;
-class KToolBarPopupAction;
-
-class Project;
-class Catalog;
-class EditorView;
-class MergeView;
-class CatalogView;
-class MsgCtxtView;
-class AltTransView;
 namespace GlossaryNS
 {
 class GlossaryView;
@@ -246,6 +255,8 @@ private Q_SLOTS:
 
     void lookupSelectionInTranslationMemory();
 
+    void updateFirstOrLastDisplayed();
+
     // statusbar indication
     void numberOfFuzziesChanged();
     void numberOfUntranslatedChanged();
