@@ -13,11 +13,12 @@
 #ifndef LOKALIZE_UPDATESTATSJOB_H
 #define LOKALIZE_UPDATESTATSJOB_H
 
+#include "metadata/filemetadata.h"
+
+#include <QObject>
 #include <QRunnable>
 
-#include <KFileItem>
-
-#include "metadata/filemetadata.h"
+class KFileItem;
 
 class UpdateStatsJob : public QObject, public QRunnable
 {
